This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[PATCH] Map Return Address on AMD64


This maps the DWARF Return Address RA to RIP, the instruction pointer
register.  This makes it possible to get rid of on of the special
hacks for the return address column in dwarf2-frame.c.

Committed,

Mark


Index: ChangeLog
from  Mark Kettenis  <kettenis@gnu.org>

	* x86-64-tdep.c (x86_64_dwarf_regmap): Map the Return Address to
	RIP.

Index: x86-64-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/x86-64-tdep.c,v
retrieving revision 1.105
diff -u -p -r1.105 x86-64-tdep.c
--- x86-64-tdep.c 29 Nov 2003 00:54:41 -0000 1.105
+++ x86-64-tdep.c 20 Dec 2003 13:25:11 -0000
@@ -157,8 +157,8 @@ static int x86_64_dwarf_regmap[] =
   /* Extended Integer Registers 8 - 15.  */
   8, 9, 10, 11, 12, 13, 14, 15,
 
-  /* Return Address RA.  Not mapped.  */
-  -1,
+  /* Return Address RA.  Mapped to RIP.  */
+  X86_64_RIP_REGNUM,
 
   /* SSE Registers 0 - 7.  */
   X86_64_XMM0_REGNUM + 0, X86_64_XMM1_REGNUM,


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]